package de.mlessmann.certassist;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import de.mlessmann.certassist.openssl.*;
import de.mlessmann.certassist.openssl.CertificateRequest.RequestType;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

class TestOpenSSLCertificateCreator {

    private OpenSSLCertificateCreator openSSLCertificateCreator;

    @BeforeEach
    void setUp() {
        CertPasswordProvider passwordProvider = mock(CertPasswordProvider.class);
        when(passwordProvider.generateNewPassword()).thenReturn("ABC-123");

        ExecutableResolver executableResolver = new ExecutableResolver();
        openSSLCertificateCreator = new OpenSSLCertificateCreator(executableResolver, passwordProvider);
    }

    @Test
    void testCertificateCreation() throws Exception {
        CertificateRequest certRequest = CertificateRequest
            .builder()
            .commonName("test.home")
            .type(RequestType.STANDALONE_CERTIFICATE)
            .subject(CertificateSubject.builder().country("DE").state("SH").locality("HH").organization("Crazy-Cats"))
            .extension(CertificateRequestExtension.builder().alternativeNames("test2.home", "test3.home"))
            .build();

        try (var cert = openSSLCertificateCreator.createCertificate(certRequest)) {
            assertThat(openSSLCertificateCreator.verifyCertificate(cert.getCertificatePath())).isEqualTo(true);
            System.out.println("Certificate created: " + cert);
        }
    }
}
